package com.ruoyi.manage.service;

import java.util.List;
import com.ruoyi.manage.domain.RecordWasteIn;

/**
 * 废品入库记录Service接口
 * 
 * @author wangh
 * @date 2024-01-29
 */
public interface IRecordWasteInService 
{
    /**
     * 查询废品入库记录
     * 
     * @param objid 废品入库记录主键
     * @return 废品入库记录
     */
    public RecordWasteIn selectRecordWasteInByObjid(Long objid);

    /**
     * 查询废品入库记录列表
     * 
     * @param recordWasteIn 废品入库记录
     * @return 废品入库记录集合
     */
    public List<RecordWasteIn> selectRecordWasteInList(RecordWasteIn recordWasteIn);

    /**
     * 新增废品入库记录
     * 
     * @param recordWasteIn 废品入库记录
     * @return 结果
     */
    public int insertRecordWasteIn(RecordWasteIn recordWasteIn);

    /**
     * 修改废品入库记录
     * 
     * @param recordWasteIn 废品入库记录
     * @return 结果
     */
    public int updateRecordWasteIn(RecordWasteIn recordWasteIn);

    /**
     * 批量删除废品入库记录
     * 
     * @param objids 需要删除的废品入库记录主键集合
     * @return 结果
     */
    public int deleteRecordWasteInByObjids(String objids);

    /**
     * 删除废品入库记录信息
     * 
     * @param objid 废品入库记录主键
     * @return 结果
     */
    public int deleteRecordWasteInByObjid(Long objid);
}
